///////////////////////////////////////////////////////////////////////////////
// luminance.h
// ===========
// convert color image to gray scale level image
// Luminance = 0.299*Red + 0.587*Green + 0.114*Blue
// Fast approx. = (2*Red + 5*Green + 1*Blue) / 8
//
//  AUTHOR: Song Ho Ahn (song.ahn@gamil.com)
// CREATED: 2006-09-21
// UPDATED: 2023-05-12
///////////////////////////////////////////////////////////////////////////////


#ifndef DIP_LUMINANCE_H
#define DIP_LUMINANCE_H

namespace dip
{

///////////////////////////////////////////////////////////////////////////////
// convert 24 bit BGR colour image to 8 bit grayscale
///////////////////////////////////////////////////////////////////////////////
bool bgr2gray(const unsigned char* in, int width, int height, unsigned char* out, bool fast=false);

///////////////////////////////////////////////////////////////////////////////
// convert 32 bit BGRA colour image to 8 bit grayscale (ignore alpha)
///////////////////////////////////////////////////////////////////////////////
bool bgra2gray(const unsigned char* in, int width, int height, unsigned char* out, bool fast=false);

///////////////////////////////////////////////////////////////////////////////
// convert 24 bit RGB colour image to 8 bit grayscale
///////////////////////////////////////////////////////////////////////////////
bool rgb2gray(const unsigned char* in, int width, int height, unsigned char* out, bool fast=false);

///////////////////////////////////////////////////////////////////////////////
// convert 32 bit RGBA colour image to 8 bit grayscale (ignore alpha)
///////////////////////////////////////////////////////////////////////////////
bool rgba2gray(const unsigned char* in, int width, int height, unsigned char* out, bool fast=false);


}
#endif
